@@ -1,21 +1,24 @@
-# modulo não oficial que ultilizar a api da squarecloud
+# squarecloud unofficial API module
+
+#=================================== Imports ======================================#
 
 import colorama
 from colorama import Fore
 colorama.init(autoreset=True)
+#===================================================================================#
+
+"""
+    modulo que contem as funções que trata os erros das funções do modulo [app]
+    ===========================================================================
+    * tratar_error --> trata todos os erros da função principal
+"""
+
 
 class error():
-    """
-        class para tratamento de erro
-    """
-    
     def __init__(self, error):
         self.teste = error
         
     def tratar_erro(self):
-        """
-            função que trata os erros da api:
-        """ 
         if self.teste == 'APP_NOT_FOUND':
             return str(Fore.RED + "Ocorreu um erro inesperado\nError: A aplicação indicada não foi achada")
         
